@@ -1,5 +1,5 @@
 # opa: An Implementation of Ordinal Pattern Analysis.
-# Copyright (C) 2022 Timothy Beechey (tim.beechey@proton.me)
+# Copyright (C) 2023 Timothy Beechey (tim.beechey@proton.me)
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 
 #' Calculates PCCs and c-values based on pairwise comparison of conditions.
 #' @param result an object of class "opafit" produced by a call to opa().
-#' @param cval_method a string, either "exact" or "stochastic
 #' @param nreps an integer, ignored if \code{cval_method = "exact"}
 #' @param digits an integer indicating how many decimal places to round values.
 #' @return \code{compare_conditions} returns a list with the following elements
@@ -37,17 +36,17 @@
 #' opamod <- opa(dat, 1:4)
 #' compare_conditions(opamod)
 #' @export
-compare_conditions <- function(result, cval_method = "stochastic", nreps = 1000L, digits=3L) {
+compare_conditions <- function(result, nreps = 1000L, digits=3L) {
   UseMethod("compare_conditions")
 }
 
 
 #' @export
-compare_conditions.default <- function(result, cval_method = "stochastic", nreps = 1000L, digits = 3L) .NotYetImplemented()
+compare_conditions.default <- function(result, nreps = 1000L, digits = 3L) .NotYetImplemented()
 
 
 #' @export
-compare_conditions.opafit <- function(result, cval_method = "stochastic", nreps = 1000L, digits = 3L) {
+compare_conditions.opafit <- function(result, nreps = 1000L, digits = 3L) {
   dat <- result$data
   n_condition_pairs <- ((ncol(dat) - 1) * ncol(dat)) / 2
   pccs <- numeric(n_condition_pairs)
@@ -55,6 +54,7 @@ compare_conditions.opafit <- function(result, cval_method = "stochastic", nreps
 
   n <- 1 # vector index
   # iterate through pairs of columns
+
   for (i in 1:(ncol(dat)-1)) {
     for (j in (i+1):ncol(dat)) {
       # get a pair of elements from the hypothesis
@@ -63,7 +63,7 @@ compare_conditions.opafit <- function(result, cval_method = "stochastic", nreps
       dat_subset <- na.omit(dat[,c(i,j)])
       pairwise_result <- opa(dat_subset, h_subset,
                              diff_threshold = result$diff_threshold,
-                             cval_method = cval_method, nreps = nreps)
+                             nreps = nreps)
       pccs[n] <- pairwise_result$group_pcc
       cvals[n] <- pairwise_result$group_cval
       n <- n + 1 # iterate vector index
@@ -78,6 +78,8 @@ compare_conditions.opafit <- function(result, cval_method = "stochastic", nreps
   # put "-" in empty cells in the upper triangle
   pcc_mat[upper.tri(pcc_mat, diag = TRUE)] <- "-"
   cval_mat[upper.tri(cval_mat, diag = TRUE)] <- "-"
+  # display 0s as < 1/nreps. e.g. if nreps=1000, display 0 as <0.001
+  cval_mat[cval_mat == "0"] <- paste0("<", toString(1/nreps))
   # convert matrices to data.frames for pretty printing
   pcc_df <- as.data.frame(pcc_mat)
   cval_df <- as.data.frame(cval_mat)
